@@ -63,9 +63,9 @@ def universal_download(url, output_dir='.', merge=True, info_only=False, **kwarg
             urls += [url.replace('\\\\/', '/') for url in q_urls]
 
         # a link href to an image is often an interesting one
-        urls += re.findall(r'href="(https?://[^"]+\.jpe?g)"', page)
-        urls += re.findall(r'href="(https?://[^"]+\.png)"', page)
-        urls += re.findall(r'href="(https?://[^"]+\.gif)"', page)
+        urls += re.findall(r'href="(https?://[^"]+\.jpe?g)"', page, re.I)
+        urls += re.findall(r'href="(https?://[^"]+\.png)"', page, re.I)
+        urls += re.findall(r'href="(https?://[^"]+\.gif)"', page, re.I)
 
         # MPEG-DASH MPD
         mpd_urls = re.findall(r'src="(https?://[^"]+\.mpd)"', page)
